@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.90 2005/04/02 07:20:01 dcransto Exp $ */
+/* $Id: gdict-applet.c,v 1.92 2005/07/05 16:01:12 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -41,8 +41,11 @@ entry_activate_cb (GtkEntry *entry, gpointer data)
   gtk_window_move (GTK_WINDOW (gdict), gdict->x, gdict->y);
   gtk_window_present (GTK_WINDOW (gdict));
     
-  if (text==NULL || *text == 0)
+  if (text == NULL || *text == 0) {
+    if (text != NULL)
+      g_free (text);
     return;
+  }
 
   gtk_editable_delete_text (GTK_EDITABLE (entry), 0, -1);
   if (gdict->search_type == SEARCH_TYPE_REGULAR)
@@ -236,6 +239,8 @@ destroy_applet (GtkWidget *widget, gpointer data)
   gtk_widget_destroy (applet->entry_widget);
   gtk_widget_destroy (applet->box);
   gtk_widget_destroy (applet->applet_widget);
+  gtk_widget_destroy (GTK_WIDGET (applet->gdict));
+  g_free (applet);
 }
 
 static void
@@ -274,27 +279,7 @@ about_cb (BonoboUIComponent *uic,
           gpointer           user_data,
           const gchar       *verbname)
 {
-  GDictApplet *applet = user_data;
-
-  if (applet->about_dialog) {
-    gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
-               gtk_widget_get_screen (applet->applet_widget));
-
-    gtk_window_present (GTK_WINDOW (applet->about_dialog));
-    return;
-  }
-
-  applet->about_dialog = gdict_about_new ();
-
-  gtk_window_set_screen (GTK_WINDOW (applet->about_dialog),
-             gtk_widget_get_screen (applet->applet_widget));
-
-  g_signal_connect (G_OBJECT (applet->about_dialog), "response",
-        G_CALLBACK (gtk_widget_destroy), NULL);
-  g_signal_connect (G_OBJECT (applet->about_dialog), "destroy",
-        G_CALLBACK (gtk_widget_destroyed), &applet->about_dialog);
-
-  gtk_widget_show (applet->about_dialog);
+	gdict_about (NULL);
 }
 
 static void
@@ -380,6 +365,7 @@ gdict_applet_new (PanelApplet *parent_applet)
 
   gdict->applet = applet;
   applet->gdict = gdict;
+  gdict_pref_load (gdict, gdict->pref);
 
   panel_applet_setup_menu_from_file (PANEL_APPLET (applet->applet_widget),
                                      NULL, "GNOME_GDictApplet.xml",
@@ -396,9 +382,6 @@ gdict_applet_new (PanelApplet *parent_applet)
                                   NULL);
   }
 
-  /* server will be contacted when an action is performed */
-  gdict->context = NULL;
-  
   component = panel_applet_get_popup_component (PANEL_APPLET(applet->applet_widget));
   
   g_signal_connect (G_OBJECT (applet->applet_widget), "size_allocate",
