@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.65 2005/05/25 15:01:40 vnoel Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.69 2005/06/20 14:52:15 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -127,7 +127,7 @@ gdict_pref_dialog_class_init (GDictPrefDialogClass *class)
   object_class->finalize = gdict_pref_dialog_finalize;
 }
 
-static web_site_edited (GtkCellRendererText *cell,
+static void web_site_edited (GtkCellRendererText *cell,
                         gchar *path_str, gchar *new_text,
                         gpointer data)
 {
@@ -154,7 +154,7 @@ static web_site_edited (GtkCellRendererText *cell,
 	
 }
 
-static web_site_toggled (GtkCellRendererToggle *cell,
+static void web_site_toggled (GtkCellRendererToggle *cell,
                          gchar                 *path_str,
                          gpointer               data)
 {
@@ -177,7 +177,7 @@ static web_site_toggled (GtkCellRendererToggle *cell,
 	gtk_list_store_set (GTK_LIST_STORE (model), &iter, ENABLED, toggle_item, -1);
 }
 
-static web_site_add (GtkButton *widget, gpointer data)
+static void web_site_add (GtkButton *widget, gpointer data)
 {
 	GDictWebSearchSite *site;
 	GDictPrefDialog *pref_dialog = data;
@@ -205,7 +205,7 @@ static web_site_add (GtkButton *widget, gpointer data)
 	gtk_tree_path_free (path);
 }
 
-static web_site_remove (GtkButton *widget, gpointer data)
+static void web_site_remove (GtkButton *widget, gpointer data)
 {
 	GDictPrefDialog *pref_dialog = data;
 	GDictWindow *gdict = pref_dialog->gdict;
@@ -222,7 +222,7 @@ static web_site_remove (GtkButton *widget, gpointer data)
 	gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 }
 
-static web_site_selected (GtkTreeSelection *selection, gpointer data)
+static void web_site_selected (GtkTreeSelection *selection, gpointer data)
 {
 	GDictPrefDialog *pref_dialog = data;
 	if (gtk_tree_selection_count_selected_rows (selection) > 0) 
@@ -231,6 +231,7 @@ static web_site_selected (GtkTreeSelection *selection, gpointer data)
 		gtk_widget_set_sensitive (pref_dialog->remove_button, FALSE);
 }
 
+void
 static set_font (GtkFontButton *widget, gpointer data)
 {
 	GDictPrefDialog *pref_dialog = data;
@@ -246,6 +247,7 @@ create_dictionary_panel (GDictPrefDialog *pref_dialog)
 {
   GtkWidget *vbox, *hbox;
 	GtkWidget *font_label, *font_button;
+	GtkWidget *menu_item;
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_box_set_spacing (GTK_BOX (vbox), 2);
@@ -322,6 +324,9 @@ create_dictionary_panel (GDictPrefDialog *pref_dialog)
   gtk_misc_set_alignment (GTK_MISC (pref_dialog->db_label), 0, 0.5);
   gtk_table_attach_defaults (pref_dialog->table, pref_dialog->db_label, 0, 1, 2, 3);
   pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
+  pref_dialog->db_sel = GTK_OPTION_MENU (gtk_option_menu_new ());
+  gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET(pref_dialog->db_sel), 1, 2, 2, 3);
+  gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->db_sel), FALSE);
 	gtk_widget_show (GTK_WIDGET (pref_dialog->db_list));
     
   pref_dialog->strat_label = gtk_label_new_with_mnemonic (_("Strat_egy:"));
@@ -329,16 +334,22 @@ create_dictionary_panel (GDictPrefDialog *pref_dialog)
   gtk_misc_set_alignment (GTK_MISC (pref_dialog->strat_label), 0, 0.5);
   gtk_table_attach_defaults (pref_dialog->table, pref_dialog->strat_label, 0, 1, 3, 4);
   pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
+  pref_dialog->strat_sel = GTK_OPTION_MENU (gtk_option_menu_new ());
+  gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET(pref_dialog->strat_sel), 1, 2, 3, 4);
+  gtk_widget_set_sensitive (GTK_WIDGET (pref_dialog->strat_sel), FALSE);
   gtk_widget_show (GTK_WIDGET (pref_dialog->strat_list));
 
-	font_label = gtk_label_new_with_mnemonic (_("Font:"));
+	font_label = gtk_label_new_with_mnemonic (_("F_ont:"));
 	gtk_label_set_justify (GTK_LABEL (font_label), GTK_JUSTIFY_LEFT);
+	gtk_misc_set_alignment (GTK_MISC (font_label), 0, 0.5);
 	gtk_table_attach_defaults (pref_dialog->table, font_label, 0, 1, 4, 5);
 	pref_dialog->font_button = gtk_font_button_new ();
 	gtk_table_attach_defaults (pref_dialog->table, pref_dialog->font_button, 1, 2, 4, 5);
 	g_signal_connect (G_OBJECT (pref_dialog->font_button), "font-set",
 										G_CALLBACK (set_font), pref_dialog);
 
+	gtk_label_set_mnemonic_widget (GTK_LABEL (font_label),
+	                               GTK_WIDGET (pref_dialog->font_button));	
   gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
 
   return vbox;
@@ -468,7 +479,6 @@ gdict_pref_dialog_set (GDictPrefDialog *pref_dialog)
                         POINTER_COLUMN, site,
                         -1);
 	}
-
 }
 
 static void 
@@ -504,10 +514,6 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog)
     
   g_signal_connect (G_OBJECT (pref_dialog), "response",
                     G_CALLBACK (response_cb), NULL);
-
-  /* To prevent dialog desctruction when pressing ESC */
-  g_signal_connect (G_OBJECT (pref_dialog), "delete_event", 
-                    G_CALLBACK (gtk_true), NULL);
 }
 
 static void
@@ -548,7 +554,7 @@ gdict_pref_dialog_new (GDictWindow *gdict)
   pref_dialog_reset_db (pref_dialog);
   pref_dialog_reset_strat (pref_dialog);
     
-  gtk_widget_show_all (GTK_WIDGET (pref_dialog));
+	gtk_widget_show_all (GTK_WIDGET (pref_dialog));
 
   return GTK_WIDGET (pref_dialog);
 }
@@ -602,10 +608,13 @@ static void
 pref_dialog_add_db (GDictPrefDialog *pref_dialog, gchar *db,
                     gchar *desc) 
 {
-  GtkWidget *menu_item;
+  GtkWidget *menu_item, *label;
   GDictWindow *gdict = pref_dialog->gdict;
     
   menu_item = gtk_menu_item_new_with_label (desc);
+  label = gtk_bin_get_child (GTK_BIN (menu_item));
+  gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
+  gtk_label_set_width_chars (GTK_LABEL (label), 30);
   g_signal_connect (G_OBJECT (menu_item), "activate", 
                     G_CALLBACK (pref_set_db_cb), pref_dialog);
   g_object_set_data (G_OBJECT (menu_item), "db_name", db);
@@ -627,10 +636,13 @@ static void
 pref_dialog_add_strat (GDictPrefDialog *pref_dialog, gchar *strat,
                        gchar *desc) 
 {
-  GtkWidget *menu_item;
+  GtkWidget *menu_item, *label;
   GDictWindow *gdict = pref_dialog->gdict;
     
   menu_item = gtk_menu_item_new_with_label (desc);
+  label = gtk_bin_get_child (GTK_BIN (menu_item));
+  gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
+  gtk_label_set_width_chars (GTK_LABEL (label), 30);
   g_signal_connect (G_OBJECT (menu_item), "activate", 
                     G_CALLBACK (pref_set_strat_cb), pref_dialog);
   g_object_set_data (G_OBJECT (menu_item), "strat_name", strat);
@@ -656,12 +668,8 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog)
   if (pref_dialog->get_db_cmd)
     dict_command_destroy (pref_dialog->get_db_cmd);
     
-  if (pref_dialog->db_sel) {
+  if (pref_dialog->db_sel)
     gtk_option_menu_remove_menu (pref_dialog->db_sel);
-    gtk_widget_destroy (GTK_WIDGET (pref_dialog->db_sel));
-    gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
-    pref_dialog->db_sel = NULL;
-  }
 
   pref_dialog->db_list = GTK_MENU (gtk_menu_new ());
     
@@ -687,6 +695,8 @@ pref_dialog_reset_db (GDictPrefDialog *pref_dialog)
       /* Could not look up search strategies, so just display a
        * label; FIXME: Memory leak
        */
+      gtk_widget_destroy (GTK_WIDGET (pref_dialog->db_sel));
+      pref_dialog->db_sel = NULL;
       error_label1 = GTK_WIDGET (gtk_label_new (_("Cannot connect to server")));
       alignment1 = GTK_WIDGET (gtk_alignment_new (0, 0.5, 0, 0));
       gtk_container_add (GTK_CONTAINER (alignment1), error_label1);
@@ -707,12 +717,8 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog)
   if (pref_dialog->get_strat_cmd)
     dict_command_destroy (pref_dialog->get_strat_cmd);
     
-  if (pref_dialog->strat_sel) {
+  if (pref_dialog->strat_sel)
     gtk_option_menu_remove_menu (pref_dialog->strat_sel);
-    gtk_widget_destroy (GTK_WIDGET (pref_dialog->strat_sel));
-    gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
-    pref_dialog->strat_sel = NULL;
-  }
     
   pref_dialog->strat_list = GTK_MENU (gtk_menu_new ());
     
@@ -736,6 +742,8 @@ pref_dialog_reset_strat (GDictPrefDialog *pref_dialog)
       /* Could not look up search strategies, so just display a
        * label; FIXME: Memory leak
        */
+      gtk_widget_destroy (GTK_WIDGET (pref_dialog->strat_sel));
+      pref_dialog->strat_sel = NULL;
       error_label2 = GTK_WIDGET (gtk_label_new (_("Cannot connect to server")));
       alignment2 = GTK_WIDGET (gtk_alignment_new (0, 0.5, 0, 0));
       gtk_container_add (GTK_CONTAINER (alignment2), error_label2);
@@ -806,11 +814,11 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
                 int num_found, gpointer data)
 {
   GDictPrefDialog *pref_dialog;
-  GtkWidget *alignment;
+  GtkWidget *alignment, *label;
   GtkOptionMenu *option_menu = NULL;
   GtkMenu *use_menu = NULL;
-  gint row = 0;
   gboolean writable;
+  int row;
     
   g_return_if_fail (data != NULL);
   g_return_if_fail (GDICT_IS_PREF_DIALOG (data));
@@ -819,21 +827,25 @@ pref_status_cb (dict_command_t *command, DictStatusCode code,
     
   if (code == DICT_STATUS_OK) {
     if (command->cmd == C_SHOW_DB) {
-      row = 2;
       use_menu = pref_dialog->db_list;
+      option_menu = pref_dialog->db_sel;
+      row = 2;
     }
     else if (command->cmd == C_SHOW_STRAT) {
-      row = 3;
       use_menu = pref_dialog->strat_list;
+      option_menu = pref_dialog->strat_sel;
+      row = 3;
+    }
+
+    if (option_menu == NULL) {
+        option_menu = GTK_OPTION_MENU (gtk_option_menu_new ());      
+      	gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET(option_menu),
+                                   1, 2, row, row+1);
     }
         
-    option_menu = GTK_OPTION_MENU (gtk_option_menu_new ());
     gtk_option_menu_set_menu (option_menu, GTK_WIDGET (use_menu));
+    gtk_widget_show (GTK_WIDGET (option_menu));
 
-    gtk_table_attach_defaults (pref_dialog->table, GTK_WIDGET (option_menu), 
-                               1, 2, row, row + 1);
-    gtk_widget_show_all (GTK_WIDGET (pref_dialog->table));
-        
     if (command->cmd == C_SHOW_DB) {
 	    pref_dialog->db_sel = option_menu;
       gtk_label_set_mnemonic_widget (GTK_LABEL (pref_dialog->db_label),
