@@ -22,7 +22,9 @@
 #  include <config.h>
 #endif
 
+#include <string.h>
 #include <unistd.h>
+#include <stdlib.h>
 #include <fcntl.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
